@@ -25,7 +25,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
-#include <gnome.h>
 #include <bacon-message-connection.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gconf/gconf-client.h>
@@ -38,7 +37,6 @@
 #include "interface.h"
 #include "proctable.h"
 #include "prettytable.h"
-#include "favorites.h"
 #include "callbacks.h"
 #include "smooth_refresh.h"
 
@@ -85,9 +83,6 @@ warning_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer d
 	if (g_str_equal (key, "/apps/procman/kill_dialog")) {
 		procdata->config.show_kill_warning = gconf_value_get_bool (value);
 	}
-	else {
-		procdata->config.show_hide_message = gconf_value_get_bool (value);
-	}
 }
 
 static void
@@ -231,7 +226,6 @@ procman_data_new (GConfClient *client)
 	pd->pids = g_hash_table_new(NULL, NULL);
 	pd->selected_process = NULL;
 	pd->timeout = 0;
-	pd->blacklist = NULL;
 	pd->cpu_graph = NULL;
 	pd->mem_graph = NULL;
 	pd->net_graph = NULL;
@@ -252,10 +246,6 @@ procman_data_new (GConfClient *client)
 							      NULL);
 	gconf_client_notify_add (client, "/apps/procman/kill_dialog", warning_changed_cb,
 				 pd, NULL, NULL);
-	pd->config.show_hide_message = gconf_client_get_bool (client, "/apps/procman/hide_message",
-							      NULL);
-	gconf_client_notify_add (client, "/apps/procman/hide_message", warning_changed_cb,
-				 pd, NULL, NULL);
 	pd->config.update_interval = gconf_client_get_int (client, "/apps/procman/update_interval", 
 							   NULL);
 	gconf_client_notify_add (client, "/apps/procman/update_interval", timeouts_changed_cb,
@@ -356,8 +346,6 @@ procman_data_new (GConfClient *client)
 	gdk_color_parse(color, &pd->config.net_out_color);
 	g_free (color);
 	
-	get_blacklist (pd, client);
-	
 	/* Sanity checks */
 	swidth = gdk_screen_width ();
 	sheight = gdk_screen_height ();
@@ -578,8 +566,6 @@ procman_save_config (ProcData *data)
 	gconf_client_set_int (client, "/apps/procman/width", data->config.width, NULL);
 	gconf_client_set_int (client, "/apps/procman/height", data->config.height, NULL);	
 	gconf_client_set_int (client, "/apps/procman/current_tab", data->config.current_tab, NULL);
-	
-	save_blacklist (data, client);
 
 	gconf_client_suggest_sync (client, NULL);
 	
@@ -663,7 +649,6 @@ int
 main (int argc, char *argv[])
 {
 	guint32 startup_timestamp;
-	GnomeProgram *procman;
 	GConfClient *client;
 	ProcData *procdata;
 	BaconMessageConnection *conn;
@@ -674,9 +659,7 @@ main (int argc, char *argv[])
 
 	startup_timestamp = get_startup_timestamp();
 
-	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
-				       LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
+	gtk_init(&argc, &argv);
 
 	conn = bacon_message_connection_new ("gnome-system-monitor");
 	if (!conn) g_error("Couldn't connect to gnome-system-monitor");
